Struct libreda_oasis::OASISWriterConfig
source · pub struct OASISWriterConfig {
pub explicit_ids: bool,
pub validation_scheme: OASISValidationScheme,
/* private fields */
}Expand description
Configuration for the output stream format.
Fields
explicit_ids: boolTells if IDs are given implicitly by a counter or are explicitly written in the file.
validation_scheme: OASISValidationSchemeType of integrity checksum used while writing the OASIS stream. Default is None (0).