Trait libreda_oasis::LayoutStreamReader [−][src]
pub trait LayoutStreamReader {
type Error;
fn read_layout<R, L>(
&self,
reader: &mut R,
layout: &mut L
) -> Result<(), Self::Error>
where
R: Read,
L: LayoutEdit<Coord = i32>;
}Expand description
Trait for reading a layout from a byte stream.
Associated Types
Required methods
fn read_layout<R, L>(
&self,
reader: &mut R,
layout: &mut L
) -> Result<(), Self::Error> where
R: Read,
L: LayoutEdit<Coord = i32>,
fn read_layout<R, L>(
&self,
reader: &mut R,
layout: &mut L
) -> Result<(), Self::Error> where
R: Read,
L: LayoutEdit<Coord = i32>,
Read a layout from a byte stream and populate the layout data structure.