LayoutStreamWriter

Trait LayoutStreamWriter 

pub trait LayoutStreamWriter {
    type Error;

    // Required method
    fn write_layout<W, L>(
        &self,
        writer: &mut W,
        layout: &L,
    ) -> Result<(), Self::Error>
       where W: Write,
             L: LayoutBase<Coord = i32>;
}
Trait for writing a layout to a byte stream.

Required Associated Types

type Error

Type of error that could happen while writing a layout.

Required Methods

fn write_layout<W, L>( &self, writer: &mut W, layout: &L, ) -> Result<(), Self::Error>
where W: Write, L: LayoutBase<Coord = i32>,

Write the layout data structure to a byte stream.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl LayoutStreamWriter for OASISStreamWriter

Writer implementation.

Source

type Error = OASISWriteError