Trait libreda_oasis::LayoutStreamWriter

source ·
pub trait LayoutStreamWriter {
    type Error;

    // Required method
    fn write_layout<W, L>(
        &self,
        writer: &mut W,
        layout: &L
    ) -> Result<(), Self::Error>
       where W: Write,
             L: LayoutBase<Coord = i32>;
}
Trait for writing a layout to a byte stream.

Required Associated Types

source

type Error

Type of error that could happen while writing a layout.

Required Methods

source

fn write_layout<W, L>( &self, writer: &mut W, layout: &L ) -> Result<(), Self::Error>
where W: Write, L: LayoutBase<Coord = i32>,

Write the layout data structure to a byte stream.

Object Safety

This trait is not object safe.

Implementors

source

impl LayoutStreamWriter for OASISStreamWriter

Writer implementation.



type Error = OASISWriteError